==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/RequestHeaderIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RequestHeaderIdentityProviderFluent<A extends RequestHeaderIdentityProviderFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCa instead.
 * @return The buildable object.
 */
@Deprecated public ConfigMapNameReference getCa();
    public ConfigMapNameReference buildCa();
    public A withCa(ConfigMapNameReference ca);
    public Boolean hasCa();
    public A withNewCa(String name);
    public RequestHeaderIdentityProviderFluent.CaNested<A> withNewCa();
    public RequestHeaderIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
    public RequestHeaderIdentityProviderFluent.CaNested<A> editCa();
    public RequestHeaderIdentityProviderFluent.CaNested<A> editOrNewCa();
    public RequestHeaderIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
    public String getChallengeURL();
    public A withChallengeURL(String challengeURL);
    public Boolean hasChallengeURL();
    public A withNewChallengeURL(String arg1);
    public A withNewChallengeURL(StringBuilder arg1);
    public A withNewChallengeURL(StringBuffer arg1);
    public A addToClientCommonNames(int index,String item);
    public A setToClientCommonNames(int index,String item);
    public A addToClientCommonNames(String... items);
    public A addAllToClientCommonNames(Collection<String> items);
    public A removeFromClientCommonNames(String... items);
    public A removeAllFromClientCommonNames(Collection<String> items);
    public List<String> getClientCommonNames();
    public String getClientCommonName(int index);
    public String getFirstClientCommonName();
    public String getLastClientCommonName();
    public String getMatchingClientCommonName(Predicate<String> predicate);
    public Boolean hasMatchingClientCommonName(Predicate<String> predicate);
    public A withClientCommonNames(List<String> clientCommonNames);
    public A withClientCommonNames(String... clientCommonNames);
    public Boolean hasClientCommonNames();
    public A addNewClientCommonName(String arg1);
    public A addNewClientCommonName(StringBuilder arg1);
    public A addNewClientCommonName(StringBuffer arg1);
    public A addToEmailHeaders(int index,String item);
    public A setToEmailHeaders(int index,String item);
    public A addToEmailHeaders(String... items);
    public A addAllToEmailHeaders(Collection<String> items);
    public A removeFromEmailHeaders(String... items);
    public A removeAllFromEmailHeaders(Collection<String> items);
    public List<String> getEmailHeaders();
    public String getEmailHeader(int index);
    public String getFirstEmailHeader();
    public String getLastEmailHeader();
    public String getMatchingEmailHeader(Predicate<String> predicate);
    public Boolean hasMatchingEmailHeader(Predicate<String> predicate);
    public A withEmailHeaders(List<String> emailHeaders);
    public A withEmailHeaders(String... emailHeaders);
    public Boolean hasEmailHeaders();
    public A addNewEmailHeader(String arg1);
    public A addNewEmailHeader(StringBuilder arg1);
    public A addNewEmailHeader(StringBuffer arg1);
    public A addToHeaders(int index,String item);
    public A setToHeaders(int index,String item);
    public A addToHeaders(String... items);
    public A addAllToHeaders(Collection<String> items);
    public A removeFromHeaders(String... items);
    public A removeAllFromHeaders(Collection<String> items);
    public List<String> getHeaders();
    public String getHeader(int index);
    public String getFirstHeader();
    public String getLastHeader();
    public String getMatchingHeader(Predicate<String> predicate);
    public Boolean hasMatchingHeader(Predicate<String> predicate);
    public A withHeaders(List<String> headers);
    public A withHeaders(String... headers);
    public Boolean hasHeaders();
    public A addNewHeader(String arg1);
    public A addNewHeader(StringBuilder arg1);
    public A addNewHeader(StringBuffer arg1);
    public String getLoginURL();
    public A withLoginURL(String loginURL);
    public Boolean hasLoginURL();
    public A withNewLoginURL(String arg1);
    public A withNewLoginURL(StringBuilder arg1);
    public A withNewLoginURL(StringBuffer arg1);
    public A addToNameHeaders(int index,String item);
    public A setToNameHeaders(int index,String item);
    public A addToNameHeaders(String... items);
    public A addAllToNameHeaders(Collection<String> items);
    public A removeFromNameHeaders(String... items);
    public A removeAllFromNameHeaders(Collection<String> items);
    public List<String> getNameHeaders();
    public String getNameHeader(int index);
    public String getFirstNameHeader();
    public String getLastNameHeader();
    public String getMatchingNameHeader(Predicate<String> predicate);
    public Boolean hasMatchingNameHeader(Predicate<String> predicate);
    public A withNameHeaders(List<String> nameHeaders);
    public A withNameHeaders(String... nameHeaders);
    public Boolean hasNameHeaders();
    public A addNewNameHeader(String arg1);
    public A addNewNameHeader(StringBuilder arg1);
    public A addNewNameHeader(StringBuffer arg1);
    public A addToPreferredUsernameHeaders(int index,String item);
    public A setToPreferredUsernameHeaders(int index,String item);
    public A addToPreferredUsernameHeaders(String... items);
    public A addAllToPreferredUsernameHeaders(Collection<String> items);
    public A removeFromPreferredUsernameHeaders(String... items);
    public A removeAllFromPreferredUsernameHeaders(Collection<String> items);
    public List<String> getPreferredUsernameHeaders();
    public String getPreferredUsernameHeader(int index);
    public String getFirstPreferredUsernameHeader();
    public String getLastPreferredUsernameHeader();
    public String getMatchingPreferredUsernameHeader(Predicate<String> predicate);
    public Boolean hasMatchingPreferredUsernameHeader(Predicate<String> predicate);
    public A withPreferredUsernameHeaders(List<String> preferredUsernameHeaders);
    public A withPreferredUsernameHeaders(String... preferredUsernameHeaders);
    public Boolean hasPreferredUsernameHeaders();
    public A addNewPreferredUsernameHeader(String arg1);
    public A addNewPreferredUsernameHeader(StringBuilder arg1);
    public A addNewPreferredUsernameHeader(StringBuffer arg1);
    public interface CaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConfigMapNameReferenceFluent<RequestHeaderIdentityProviderFluent.CaNested<N>> {

            public N and();
            public N endCa();    }


}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/RequestHeaderIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RequestHeaderIdentityProviderFluent<A extends RequestHeaderIdentityProviderFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCa instead.
 * @return The buildable object.
 */
@Deprecated public ConfigMapNameReference getCa();
    public ConfigMapNameReference buildCa();
    public A withCa(ConfigMapNameReference ca);
    public Boolean hasCa();
    public A withNewCa(String name);
    public io.fabric8.openshift.api.model.RequestHeaderIdentityProviderFluent.CaNested<A> withNewCa();
    public io.fabric8.openshift.api.model.RequestHeaderIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
    public io.fabric8.openshift.api.model.RequestHeaderIdentityProviderFluent.CaNested<A> editCa();
    public io.fabric8.openshift.api.model.RequestHeaderIdentityProviderFluent.CaNested<A> editOrNewCa();
    public io.fabric8.openshift.api.model.RequestHeaderIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
    public String getChallengeURL();
    public A withChallengeURL(String challengeURL);
    public Boolean hasChallengeURL();
    public A withNewChallengeURL(StringBuilder arg1);
    public A withNewChallengeURL(int[] arg1,int arg2,int arg3);
    public A withNewChallengeURL(char[] arg1);
    public A withNewChallengeURL(StringBuffer arg1);
    public A withNewChallengeURL(byte[] arg1,int arg2);
    public A withNewChallengeURL(byte[] arg1);
    public A withNewChallengeURL(char[] arg1,int arg2,int arg3);
    public A withNewChallengeURL(byte[] arg1,int arg2,int arg3);
    public A withNewChallengeURL(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewChallengeURL(String arg1);
    public A addToClientCommonNames(int index,String item);
    public A setToClientCommonNames(int index,String item);
    public A addToClientCommonNames(String... items);
    public A addAllToClientCommonNames(Collection<String> items);
    public A removeFromClientCommonNames(String... items);
    public A removeAllFromClientCommonNames(Collection<String> items);
    public List<String> getClientCommonNames();
    public String getClientCommonName(int index);
    public String getFirstClientCommonName();
    public String getLastClientCommonName();
    public String getMatchingClientCommonName(Predicate<String> predicate);
    public Boolean hasMatchingClientCommonName(Predicate<String> predicate);
    public A withClientCommonNames(List<String> clientCommonNames);
    public A withClientCommonNames(String... clientCommonNames);
    public Boolean hasClientCommonNames();
    public A addNewClientCommonName(StringBuilder arg1);
    public A addNewClientCommonName(int[] arg1,int arg2,int arg3);
    public A addNewClientCommonName(char[] arg1);
    public A addNewClientCommonName(StringBuffer arg1);
    public A addNewClientCommonName(byte[] arg1,int arg2);
    public A addNewClientCommonName(byte[] arg1);
    public A addNewClientCommonName(char[] arg1,int arg2,int arg3);
    public A addNewClientCommonName(byte[] arg1,int arg2,int arg3);
    public A addNewClientCommonName(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewClientCommonName(String arg1);
    public A addToEmailHeaders(int index,String item);
    public A setToEmailHeaders(int index,String item);
    public A addToEmailHeaders(String... items);
    public A addAllToEmailHeaders(Collection<String> items);
    public A removeFromEmailHeaders(String... items);
    public A removeAllFromEmailHeaders(Collection<String> items);
    public List<String> getEmailHeaders();
    public String getEmailHeader(int index);
    public String getFirstEmailHeader();
    public String getLastEmailHeader();
    public String getMatchingEmailHeader(Predicate<String> predicate);
    public Boolean hasMatchingEmailHeader(Predicate<String> predicate);
    public A withEmailHeaders(List<String> emailHeaders);
    public A withEmailHeaders(String... emailHeaders);
    public Boolean hasEmailHeaders();
    public A addNewEmailHeader(StringBuilder arg1);
    public A addNewEmailHeader(int[] arg1,int arg2,int arg3);
    public A addNewEmailHeader(char[] arg1);
    public A addNewEmailHeader(StringBuffer arg1);
    public A addNewEmailHeader(byte[] arg1,int arg2);
    public A addNewEmailHeader(byte[] arg1);
    public A addNewEmailHeader(char[] arg1,int arg2,int arg3);
    public A addNewEmailHeader(byte[] arg1,int arg2,int arg3);
    public A addNewEmailHeader(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewEmailHeader(String arg1);
    public A addToHeaders(int index,String item);
    public A setToHeaders(int index,String item);
    public A addToHeaders(String... items);
    public A addAllToHeaders(Collection<String> items);
    public A removeFromHeaders(String... items);
    public A removeAllFromHeaders(Collection<String> items);
    public List<String> getHeaders();
    public String getHeader(int index);
    public String getFirstHeader();
    public String getLastHeader();
    public String getMatchingHeader(Predicate<String> predicate);
    public Boolean hasMatchingHeader(Predicate<String> predicate);
    public A withHeaders(List<String> headers);
    public A withHeaders(String... headers);
    public Boolean hasHeaders();
    public A addNewHeader(StringBuilder arg1);
    public A addNewHeader(int[] arg1,int arg2,int arg3);
    public A addNewHeader(char[] arg1);
    public A addNewHeader(StringBuffer arg1);
    public A addNewHeader(byte[] arg1,int arg2);
    public A addNewHeader(byte[] arg1);
    public A addNewHeader(char[] arg1,int arg2,int arg3);
    public A addNewHeader(byte[] arg1,int arg2,int arg3);
    public A addNewHeader(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewHeader(String arg1);
    public String getLoginURL();
    public A withLoginURL(String loginURL);
    public Boolean hasLoginURL();
    public A withNewLoginURL(StringBuilder arg1);
    public A withNewLoginURL(int[] arg1,int arg2,int arg3);
    public A withNewLoginURL(char[] arg1);
    public A withNewLoginURL(StringBuffer arg1);
    public A withNewLoginURL(byte[] arg1,int arg2);
    public A withNewLoginURL(byte[] arg1);
    public A withNewLoginURL(char[] arg1,int arg2,int arg3);
    public A withNewLoginURL(byte[] arg1,int arg2,int arg3);
    public A withNewLoginURL(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLoginURL(String arg1);
    public A addToNameHeaders(int index,String item);
    public A setToNameHeaders(int index,String item);
    public A addToNameHeaders(String... items);
    public A addAllToNameHeaders(Collection<String> items);
    public A removeFromNameHeaders(String... items);
    public A removeAllFromNameHeaders(Collection<String> items);
    public List<String> getNameHeaders();
    public String getNameHeader(int index);
    public String getFirstNameHeader();
    public String getLastNameHeader();
    public String getMatchingNameHeader(Predicate<String> predicate);
    public Boolean hasMatchingNameHeader(Predicate<String> predicate);
    public A withNameHeaders(List<String> nameHeaders);
    public A withNameHeaders(String... nameHeaders);
    public Boolean hasNameHeaders();
    public A addNewNameHeader(StringBuilder arg1);
    public A addNewNameHeader(int[] arg1,int arg2,int arg3);
    public A addNewNameHeader(char[] arg1);
    public A addNewNameHeader(StringBuffer arg1);
    public A addNewNameHeader(byte[] arg1,int arg2);
    public A addNewNameHeader(byte[] arg1);
    public A addNewNameHeader(char[] arg1,int arg2,int arg3);
    public A addNewNameHeader(byte[] arg1,int arg2,int arg3);
    public A addNewNameHeader(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewNameHeader(String arg1);
    public A addToPreferredUsernameHeaders(int index,String item);
    public A setToPreferredUsernameHeaders(int index,String item);
    public A addToPreferredUsernameHeaders(String... items);
    public A addAllToPreferredUsernameHeaders(Collection<String> items);
    public A removeFromPreferredUsernameHeaders(String... items);
    public A removeAllFromPreferredUsernameHeaders(Collection<String> items);
    public List<String> getPreferredUsernameHeaders();
    public String getPreferredUsernameHeader(int index);
    public String getFirstPreferredUsernameHeader();
    public String getLastPreferredUsernameHeader();
    public String getMatchingPreferredUsernameHeader(Predicate<String> predicate);
    public Boolean hasMatchingPreferredUsernameHeader(Predicate<String> predicate);
    public A withPreferredUsernameHeaders(List<String> preferredUsernameHeaders);
    public A withPreferredUsernameHeaders(String... preferredUsernameHeaders);
    public Boolean hasPreferredUsernameHeaders();
    public A addNewPreferredUsernameHeader(StringBuilder arg1);
    public A addNewPreferredUsernameHeader(int[] arg1,int arg2,int arg3);
    public A addNewPreferredUsernameHeader(char[] arg1);
    public A addNewPreferredUsernameHeader(StringBuffer arg1);
    public A addNewPreferredUsernameHeader(byte[] arg1,int arg2);
    public A addNewPreferredUsernameHeader(byte[] arg1);
    public A addNewPreferredUsernameHeader(char[] arg1,int arg2,int arg3);
    public A addNewPreferredUsernameHeader(byte[] arg1,int arg2,int arg3);
    public A addNewPreferredUsernameHeader(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewPreferredUsernameHeader(String arg1);
    public interface CaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConfigMapNameReferenceFluent<io.fabric8.openshift.api.model.RequestHeaderIdentityProviderFluent.CaNested<N>> {

            public N and();
            public N endCa();    }


}
